% For use with Matlab
% Copyright (C) 2019 -- Jérôme Mendes <jermendes@gmail.com> or <jermendes@isr.uc.pt>, Rui Araújo <rui@isr.uc.pt>
% Jérôme Mendes, Francisco Souza, and Rui Araújo. "Online Evolving Fuzzy Control Design: An Application to a CSTR Plant". In Proc. IEEE 15th International Conference on Industrial Informatics (INDIN 2017), 2017.
% The "SEDFLC toolbox" comes with ABSOLUTELY NO WARRANTY;
% In case of publication of any application of this method, please, cite the work:
% Jérôme Mendes, Francisco Souza and Rui Araújo. 
% Online Evolving Fuzzy Control Design: An Application to a CSTR Plant.
% In Proc. IEEE 15th International Conference on Industrial Informatics (INDIN 2017), pages 1-8, Emden, Germany, July 24 - July 17
% DOI: https://doi.org/10.1109/INDIN.2017.8104774
% http://www.isr.uc.pt/~jermendes/    ;     http://www.isr.uc.pt/~rui/

function [command_signal] = FuzzyController (data_input, x)
%% Description
% This function obtains the fuzzy control signal - equation 8

%% Function inputs
% x - Struct with all fuzzy control parameters
% data_input -  values of the input variable

%% Function output
% command_signal -  fuzzy control signal - equation 8

%% Variables Definition
n_var= size(x, 2); % number of inputs variables
command_signal = 0.0;

%% Obtain variable \psi (eq. 11)
psi = Psi(data_input, x);

k = 1;% Auxiliary variable

for j=1:n_var %  for all input variables

    n_rules = size( x(j).Rules,1 ); % number of rules of input variable j

    for i = 1:n_rules % for all rules of input variable j
        
        command_signal = command_signal + psi(k)*x(j).Rules(i,4); % fuzzy control signal  - equation 8
        k = k +1;
    end

end

end